Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(149)

Unified Diff: views/controls/tree/tree_view.cc

Issue 2862025: Canvas refactoring part 2.... (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: Created 10 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « views/controls/table/table_view.cc ('k') | views/drag_utils.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: views/controls/tree/tree_view.cc
===================================================================
--- views/controls/tree/tree_view.cc (revision 50452)
+++ views/controls/tree/tree_view.cc (working copy)
@@ -13,8 +13,8 @@
#include "base/keyboard_codes.h"
#include "base/stl_util-inl.h"
#include "base/win_util.h"
-#include "gfx/canvas.h"
-#include "gfx/canvas_paint.h"
+#include "gfx/canvas_skia.h"
+#include "gfx/canvas_skia_paint.h"
#include "gfx/favicon_size.h"
#include "gfx/icon_util.h"
#include "gfx/point.h"
@@ -688,7 +688,7 @@
// IDR_FOLDER_CLOSED if they aren't already.
if (model_images[i].width() != width ||
model_images[i].height() != height) {
- gfx::Canvas canvas(width, height, false);
+ gfx::CanvasSkia canvas(width, height, false);
// Make the background completely transparent.
canvas.drawColor(SK_ColorBLACK, SkXfermode::kClear_Mode);
@@ -739,13 +739,13 @@
return 1;
case WM_PAINT: {
- gfx::CanvasPaint canvas(window);
+ gfx::CanvasSkiaPaint canvas(window);
if (canvas.isEmpty())
return 0;
HDC dc = canvas.beginPlatformPaint();
if (base::i18n::IsRTL()) {
// gfx::Canvas ends up configuring the DC with a mode of GM_ADVANCED.
// For some reason a graphics mode of ADVANCED triggers all the text
// to be mirrored when RTL. Set the mode back to COMPATIBLE and
// explicitly set the layout. Additionally SetWorldTransform and
@@ -739,13 +739,13 @@
HDC dc = canvas.beginPlatformPaint();
if (base::i18n::IsRTL()) {
- // gfx::Canvas ends up configuring the DC with a mode of GM_ADVANCED.
+ // gfx::CanvasSkia ends up configuring the DC with a mode of GM_ADVANCED.
// For some reason a graphics mode of ADVANCED triggers all the text
// to be mirrored when RTL. Set the mode back to COMPATIBLE and
« no previous file with comments | « views/controls/table/table_view.cc ('k') | views/drag_utils.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698